# MetEva
MetEva aims to provide fast and efficient evaluation and validation methods and processes for weather forecasting products. From numerical models, objective forecasting methods, refined grid forecasts to forecast product application, MetEva can play a role in promoting cross-process and cross-departmental verification information sharing, providing technical support for improving forecast quality.

Generally, Meteva is a pure python program library that provides commonly used algorithms for reading and writing , mapping, and evalution of various kind of waather forecast data. Meanwhile, MetEva provides a wealth of examples for the use of validation algorithms. It contains 20 + items of data reading and writing functions, 10 + items of convenient plotting functions, 100 + items of basic valadation algorithms, 20 + items of application tools for evaluation and validation, and supports 30 + classification methods for fine-scale evaluation. 

## Version 
MetEva-1.9.1.4

## Dependencies
numpy>=1.12.1, pandas>=1.0.4, netCDF4>=1.4.2, scipy>=0.19.0, xarray>=0.10.0, scikit-learn>=0.21.2
matplotlib>=3.0.0, httplib2>=0.12.0, protobuf < 3.20.0, pyshp>=2.1.0, tables>=3.4.4, urllib3>=1.21.1

## Install
Please install metdig under anaconda enviroment.
The installation can be completed by executing the command "pip install meteva".
This library only supports running on Python versions above 3.7.

## More Information
For detailed usage instructions, please refer to the content of this website: https://www.showdoc.cn/meteva

#nmc_verification 提供气象产品检验相关程序 说明文档详见： https://www.showdoc.cc/meteva
